program NkVp;

{$IMPORTEDDATA OFF}
{$R *.RES}

uses ActiveX, NTypes, NLib, NSys, NApp, NForm, NConf, NResource, MainForm, Player;

type
  TNkVpApp = class(TApp)
    procedure Init; override;
    destructor Destroy; override;
  end;

procedure TNkVpApp.Init;
var
  i: Integer;
  opt: WideChar;
  eflag, fflag: Boolean;
  keymap: TConf;
begin
  eflag := False;
  fflag := False;

  with ArgParser do
  begin
    while GetOpt(opt) do
      case opt of
        'e': eflag := True;
        'f': fflag := True;
      else
        Error('usage: nkvp [-ef] [file ...]');
        ExitCode := 1;
        Exit;
      end;
    Argv := Args;
  end;

  if Length(Argv) > 0 then
    try
      for i := 0 to High(Argv) do
        if not IsUrl(Argv[i]) then
          Argv[i] := AbsPath(Argv[i]);
      SendToRemoteForm(TNkVpMainForm, JoinCommandLine(Argv));
      Exit;
    except
      on E: EOSError do ;
    end;

  ProfDir := GetEnv('NKTOOLSPROF');
  if ProfDir = '' then
    ProfDir := DirName(ProgPath)
  else
    ProfDir := JoinPath([ProfDir, 'nkvp']);

  Config := TConf.Create;
  Config.LoadFromFile(JoinPath([ProfDir, 'position']));
  Config.Read(ResourceText('CONFIG')); // override 'w' and 'h'
  Config.LoadFromFile(JoinPath([ProfDir, 'config']));

  keymap := TConf.Create;
  keymap.Read(ResourceText('KEYMAP'));
  keymap.LoadFromFile(JoinPath([ProfDir, 'keymap']));

  MainForm := TNkVpMainForm.Create;
  with MainForm as TNkVpMainForm do begin
    Command.BindKeys(keymap);
    keymap.Free;
    Accel := Command.AccelHandle;

    ExitAtEnd := eflag;
    for i := 0 to High(Argv) do
      Playlist.Add(Argv[i]);
    Show;
    LoadFromPlaylist(0, not FitMovie);
    if Player.Loaded and fflag then
      cmFullScreen;
  end;

  Run;
end;

destructor TNkVpApp.Destroy;
begin
  MainForm.Free;
  Config.Free;
end;

begin
  IsMultiThread := True;
  CoInitializeEx(nil, COINIT_APARTMENTTHREADED or COINIT_DISABLE_OLE1DDE);
  App := TNkVpApp.Create('NkVp');
  try
    try
      App.Init;
    except
      App.Fatal;
    end;
  finally
    App.Free;
    CoUninitialize;
  end;
end.
